@@ -44,6 +44,15 @@ class RGB:
                 green=(value >> 8) & 0xFF,
                 blue=value & 0xFF
             )
+
+    @staticmethod
+    def from_int_with_alpha(value: int) -> "RGB":
+        return RGB(
+            red=(value >> 24) & 0xFF,
+            green=(value >> 16) & 0xFF,
+            blue=(value >> 8) & 0xFF,
+            alpha=value & 0xFF
+        )
     
 class Player:
     def __init__(
@@ -106,7 +115,7 @@ class Player:
     
     @property
     def color(self) -> RGB:
-        return RGB.from_int(funcs.get_player_colour(self._id))
+        return RGB.from_int_with_alpha(funcs.get_player_colour(self._id))
 
     @color.setter
     def color(self, color: RGB):
@@ -1568,11 +1577,11 @@ class CheckPoint:
     def __del__(self):
         self.delete()
 
-    def __new__(cls, pickup_id: int):
-        if not funcs.check_entity_exists(vcmpEntityPool.vcmpEntityPoolCheckPoint, pickup_id):
+    def __new__(cls, checkpoint_id: int):
+        if not funcs.check_entity_exists(vcmpEntityPool.vcmpEntityPoolCheckPoint, checkpoint_id):
             return None
         
-        checkpoint = next((checkpoint for checkpoint in _checkpoints if checkpoint.id == pickup_id), None)
+        checkpoint = next((checkpoint for checkpoint in _checkpoints if checkpoint.id == checkpoint_id), None)
         if checkpoint is None:
             checkpoint = super().__new__(cls)
             _checkpoints.append(checkpoint)
@@ -1698,10 +1707,10 @@ class Object:
     def __del__(self):
         self.delete()
 
-    def __new__(cls, pickup_id: int):
-        if not funcs.check_entity_exists(vcmpEntityPool.vcmpEntityPoolObject, pickup_id):
+    def __new__(cls, object_id: int):
+        if not funcs.check_entity_exists(vcmpEntityPool.vcmpEntityPoolObject, object_id):
             return None
-        object = next((object for object in _objects if object.id == pickup_id), None)
+        object = next((object for object in _objects if object.id == object_id), None)
         if object is None:
             object = super().__new__(cls)
             _objects.append(object)
@@ -1738,7 +1747,7 @@ class Marker:
     
     @property
     def color(self):
-        return RGB.from_int(funcs.get_coord_blip_info(self._id)[5])
+        return RGB.from_int_with_alpha(funcs.get_coord_blip_info(self._id)[5])
 
     def delete(self):
         """
@@ -1748,7 +1757,16 @@ class Marker:
             return
         funcs.destroy_coord_blip(self._id)
         _markers.remove(self)
-            
+
+    def __new__(cls, marker_id: int) -> Optional['Marker']:
+        if not funcs.check_entity_exists(vcmpEntityPool.vcmpEntityPoolBlip, marker_id):
+            return None
+        marker = next((marker for marker in _markers if marker.id == marker_id), None)
+        if marker is None:
+            marker = super().__new__(cls)
+            _markers.append(marker)
+        return marker
+
 _players: list[Player] = []
 _vehicles: list[Vehicle] = []
 _pickups: list[Pickup] = []
@@ -1793,12 +1811,11 @@ def get_checkpoint_from_id(
 ) -> Optional[CheckPoint]:
     return next((checkpoint for checkpoint in _checkpoints if checkpoint.id == checkpoint_id), None)
     
-
 def search_from_pool(
     pool: vcmpEntityPool,
 ) -> list[int]:
     max = _pools_max[pool]
-    return [i for i in range(max) if not funcs.check_entity_exists(pool, i)]
+    return [i for i in range(max) if funcs.check_entity_exists(pool, i)]
 
 def _update_pool(
     pool: vcmpEntityPool,
@@ -1828,8 +1845,6 @@ def update_pool(
             _checkpoints = _update_pool(pool, CheckPoint)
         case vcmpEntityPool.vcmpEntityPoolBlip:
             _markers = _update_pool(pool, Marker)
-            
-
 
 def update_pools():
     for pool in _pools_max.keys():
@@ -1867,7 +1882,6 @@ def _on_pre_entity_pool_update(
             CheckPoint(id)
         case vcmpEntityPool.vcmpEntityPoolBlip:
             Marker(id)
-    
 
 def _on_post_entity_pool_update(
     pool: int,
@@ -1885,7 +1899,6 @@ def _on_post_entity_pool_update(
             instance = next((pickup for pickup in _pickups if pickup.id == id), None)
             if instance is not None:
                 _pickups.remove(instance)
-    
 
 setattr(calls, "on_pre_player_connect", _on_pre_player_connect)
 setattr(calls, "on_post_player_disconnect", _on_post_player_disconnect)
